==> QupZilla-2.2.3.tar.xz: QupZilla-2.2.3/src/plugins/FlashCookieManager/translations/zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>儲存的 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>尋找：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;沒有選擇任何 Flash Cookie&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>最後更改：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>名稱：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation>來源：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>已取出的 latin1 字串：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>這些 Flash Cookie 已儲存在您的電腦上：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>來源</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>從硬碟上重新載入</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>路徑：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>點擊以開啟所在的資料夾</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>移除所有 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>移除 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Flash Cookie 過濾</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie 白名單&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>來自這些來源的 Flash Cookie 將不會被自動刪除。(偵測到它們時也不會通知使用者。)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie 黑名單&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>來自這些來源的 Flash Cookie 將會在不通知使用者的情況下自動刪除。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie 設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>自動模式：Flash 資料目錄將會被定期檢查，且在黑名單裡的 Flash Cookie 將會被自動刪除。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;注意：&lt;/span&gt; 這個設定只會被應用在 Flash Cookie 上，要管理 HTTP 的 Cookie 請使用 &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies 管理員&lt;/span&gt;。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation>通知：每個不在黑名單及白名單裡的 Flash Cookie 出現時將會通知使用者。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>在離開╱啟動時刪除所有 Flash Cookie。(除了在白名單裡面的那些以外)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>您確定要刪除電腦上所有的 Flash Cookie？</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation> (設定)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation>位元組</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>移除 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation> [新]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>加入到白名單</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation>已在白名單中！</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation>伺服器「%1」已在黑名單中，請先移除它。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>加入到黑名單</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation>來源「%1」已在白名單中，請先移除它。</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>偵測到新的 Flash Cookie！</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>偵測到一個新的 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>偵測到 %1 個新的 Flash Cookie</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="129"/>
        <source>Flash Cookie Manager</source>
        <translation>Flash Cookie 管理員</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="357"/>
        <source>Show Flash Cookie Manager</source>
        <translation>顯示 Flash Cookie 管理員</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="439"/>
        <source>!default</source>
        <translation>!預設</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="451"/>
        <source>!other</source>
        <translation>!其他</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.6.tar.xz: QupZilla-2.2.6/src/plugins/FlashCookieManager/translations/zh_TW.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_TW" version="2.1">
<context>
    <name>FCM_Button</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="58"/>
        <source>Flash Cookie Manager button</source>
        <translation>Flash Cookie 管理器按鈕</translation>
    </message>
</context>
<context>
    <name>FCM_Dialog</name>
    <message>
        <location filename="../fcm_dialog.ui" line="14"/>
        <source>Flash Cookies</source>
        <translation>Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="24"/>
        <source>Stored Flash Cookies</source>
        <translation>儲存的 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="45"/>
        <source>Find: </source>
        <translation>尋找：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="73"/>
        <location filename="../fcm_dialog.ui" line="120"/>
        <location filename="../fcm_dialog.ui" line="130"/>
        <location filename="../fcm_dialog.ui" line="140"/>
        <location filename="../fcm_dialog.ui" line="256"/>
        <location filename="../fcm_dialog.cpp" line="151"/>
        <location filename="../fcm_dialog.cpp" line="152"/>
        <location filename="../fcm_dialog.cpp" line="153"/>
        <location filename="../fcm_dialog.cpp" line="154"/>
        <source>&lt;flash cookie not selected&gt;</source>
        <translation>&lt;沒有選擇任何 Flash Cookie&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="83"/>
        <source>Last Modified:</source>
        <translation>最後更改：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="96"/>
        <source>Name:</source>
        <translation>名稱：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="106"/>
        <source>Size:</source>
        <translation>大小：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="113"/>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <source>Origin:</source>
        <translation>來源：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="152"/>
        <source>Extracted latin1 strings:</source>
        <translation>已取出的 latin1 字串：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="182"/>
        <source>These flash cookies are stored on your computer:</source>
        <translation>這些 Flash Cookie 已儲存在您的電腦上：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="202"/>
        <source>Origin</source>
        <translation>來源</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="227"/>
        <source>Reload from disk</source>
        <translation>從硬碟上重新載入</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="240"/>
        <source>Path:</source>
        <translation>路徑：</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="253"/>
        <source>Click to open containing folder</source>
        <translation>點擊以開啟所在的資料夾</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="276"/>
        <source>Remove all flash cookies</source>
        <translation>移除所有 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="283"/>
        <location filename="../fcm_dialog.cpp" line="156"/>
        <source>Remove flash cookies</source>
        <translation>移除 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="308"/>
        <source>Flash Cookies Filtering</source>
        <translation>Flash Cookie 過濾</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="316"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie whitelist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie 白名單&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="348"/>
        <location filename="../fcm_dialog.ui" line="416"/>
        <source>Remove</source>
        <translation>移除</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="355"/>
        <location filename="../fcm_dialog.ui" line="423"/>
        <source>Add</source>
        <translation>新增</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="364"/>
        <source>Flash cookies from these origins will not be deleted automatically. (Also detection of them will not be notified to user.)</source>
        <translation>來自這些來源的 Flash Cookie 將不會被自動刪除。(偵測到它們時也不會通知使用者。)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="374"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie blacklist&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash cookie 黑名單&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="381"/>
        <source>Flash cookies from these origins will be deleted without any notification.</source>
        <translation>來自這些來源的 Flash Cookie 將會在不通知使用者的情況下自動刪除。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="442"/>
        <source>Settings</source>
        <translation>設定</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="453"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie Settings&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Flash Cookie 設定&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="475"/>
        <source>Auto mode: The flash data directory will be checked regularly. and flash cookies in blacklist will be deleted automatically.</source>
        <translation>自動模式：Flash 資料目錄將會被定期檢查，且在黑名單裡的 Flash Cookie 將會被自動刪除。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="510"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; This settings are just applied to flash cookies, to manage HTTP cookies use &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies Manager&lt;/span&gt;. &lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;注意：&lt;/span&gt; 這個設定只會被應用在 Flash Cookie 上，要管理 HTTP 的 Cookie 請使用 &lt;span style=&quot; font-weight:600;&quot;&gt;Cookies 管理員&lt;/span&gt;。&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="538"/>
        <source>Notification: User will be notified for every new flash cookie that is not in blacklist and whitelist.</source>
        <translation>通知：每個不在黑名單及白名單裡的 Flash Cookie 出現時將會通知使用者。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.ui" line="565"/>
        <source>Delete all flash cookies on exit/start. (except those are in whitelist)</source>
        <translation>在離開╱啟動時刪除所有 Flash Cookie。(除了在白名單裡面的那些以外)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="76"/>
        <source>Search</source>
        <translation>搜尋</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="93"/>
        <source>Confirmation</source>
        <translation>確認</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="94"/>
        <source>Are you sure you want to delete all flash cookies on your computer?</source>
        <translation>您確定要刪除電腦上所有的 Flash Cookie？</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="166"/>
        <location filename="../fcm_dialog.cpp" line="237"/>
        <source> (settings)</source>
        <translation> (設定)</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="169"/>
        <source> Byte</source>
        <translation>位元組</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="175"/>
        <source>Remove flash cookie</source>
        <translation>移除 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="241"/>
        <source> [new]</source>
        <translation> [新]</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="277"/>
        <location filename="../fcm_dialog.cpp" line="375"/>
        <source>Add to whitelist</source>
        <translation>加入到白名單</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>Already whitelisted!</source>
        <translation>已在白名單中！</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="289"/>
        <source>The server &quot;%1&quot; is already in blacklist, please remove it first.</source>
        <translation>伺服器「%1」已在黑名單中，請先移除它。</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="305"/>
        <location filename="../fcm_dialog.cpp" line="374"/>
        <source>Add to blacklist</source>
        <translation>加入到黑名單</translation>
    </message>
    <message>
        <location filename="../fcm_dialog.cpp" line="317"/>
        <source>The origin &quot;%1&quot; is already in whitelist, please remove it first.</source>
        <translation>來源「%1」已在白名單中，請先移除它。</translation>
    </message>
</context>
<context>
    <name>FCM_Notification</name>
    <message>
        <location filename="../fcm_notification.ui" line="45"/>
        <source>New flash cookie was detected!</source>
        <translation>偵測到新的 Flash Cookie！</translation>
    </message>
    <message>
        <location filename="../fcm_notification.ui" line="52"/>
        <source>View</source>
        <translation>檢視</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="34"/>
        <source>A new flash cookie was detected</source>
        <translation>偵測到一個新的 Flash Cookie</translation>
    </message>
    <message>
        <location filename="../fcm_notification.cpp" line="37"/>
        <source>%1 new flash cookies were detected</source>
        <translation>偵測到 %1 個新的 Flash Cookie</translation>
    </message>
</context>
<context>
    <name>FCM_Plugin</name>
    <message>
        <location filename="../fcm_plugin.cpp" line="147"/>
        <location filename="../fcm_plugin.cpp" line="377"/>
        <source>Flash Cookie Manager</source>
        <translation>Flash Cookie 管理員</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="378"/>
        <source>Show Flash Cookie Manager</source>
        <translation>顯示 Flash Cookie 管理員</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="459"/>
        <source>!default</source>
        <translation>!預設</translation>
    </message>
    <message>
        <location filename="../fcm_plugin.cpp" line="471"/>
        <source>!other</source>
        <translation>!其他</translation>
    </message>
</context>
</TS>
